# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.shared_step_response import SharedStepResponse

class TestSharedStepResponse(unittest.TestCase):
    """SharedStepResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SharedStepResponse:
        """Test SharedStepResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SharedStepResponse`
        """
        model = SharedStepResponse()
        if include_optional:
            return SharedStepResponse(
                status = True,
                result = qaseio.models.shared_step.SharedStep(
                    hash = '', 
                    title = '', 
                    action = '', 
                    expected_result = '', 
                    steps = [
                        qaseio.models.shared_step_content.SharedStepContent(
                            data = '', 
                            hash = '', 
                            action = '', 
                            expected_result = '', 
                            attachments = [
                                qaseio.models.attachment_hash.AttachmentHash(
                                    size = 56, 
                                    mime = '', 
                                    filename = '', 
                                    url = '', 
                                    hash = '', )
                                ], )
                        ], 
                    data = '', 
                    cases = [
                        56
                        ], 
                    cases_count = 56, 
                    created = '2021-12-30 19:23:59', 
                    updated = '2021-12-30 19:23:59', 
                    created_at = '2021-12-30T19:23:59Z', 
                    updated_at = '2021-12-30T19:23:59Z', )
            )
        else:
            return SharedStepResponse(
        )
        """

    def testSharedStepResponse(self):
        """Test SharedStepResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
