# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.project_list_response import ProjectListResponse

class TestProjectListResponse(unittest.TestCase):
    """ProjectListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectListResponse:
        """Test ProjectListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectListResponse`
        """
        model = ProjectListResponse()
        if include_optional:
            return ProjectListResponse(
                status = True,
                result = qaseio.models.project_list_response_all_of_result.ProjectListResponse_allOf_result(
                    total = 56, 
                    filtered = 56, 
                    count = 56, 
                    entities = [
                        qaseio.models.project.Project(
                            title = '', 
                            code = '', 
                            counts = qaseio.models.project_counts.Project_counts(
                                cases = 56, 
                                suites = 56, 
                                milestones = 56, 
                                runs = qaseio.models.project_counts_runs.Project_counts_runs(
                                    total = 56, 
                                    active = 56, ), 
                                defects = qaseio.models.project_counts_defects.Project_counts_defects(
                                    total = 56, 
                                    open = 56, ), ), )
                        ], )
            )
        else:
            return ProjectListResponse(
        )
        """

    def testProjectListResponse(self):
        """Test ProjectListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
