# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.projects_api import ProjectsApi


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProjectsApi()

    def tearDown(self) -> None:
        pass

    def test_create_project(self) -> None:
        """Test case for create_project

        Create new project.
        """
        pass

    def test_delete_project(self) -> None:
        """Test case for delete_project

        Delete Project by code.
        """
        pass

    def test_get_project(self) -> None:
        """Test case for get_project

        Get Project by code.
        """
        pass

    def test_get_projects(self) -> None:
        """Test case for get_projects

        Get All Projects.
        """
        pass

    def test_grant_access_to_project(self) -> None:
        """Test case for grant_access_to_project

        Grant access to project by code.
        """
        pass

    def test_revoke_access_to_project(self) -> None:
        """Test case for revoke_access_to_project

        Revoke access to project by code.
        """
        pass


if __name__ == '__main__':
    unittest.main()
