# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.result_update import ResultUpdate

class TestResultUpdate(unittest.TestCase):
    """ResultUpdate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultUpdate:
        """Test ResultUpdate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResultUpdate`
        """
        model = ResultUpdate()
        if include_optional:
            return ResultUpdate(
                status = 'in_progress',
                time_ms = 0,
                defect = True,
                attachments = [
                    ''
                    ],
                stacktrace = '',
                comment = '',
                steps = [
                    qaseio.models.test_step_result_create.TestStepResultCreate(
                        position = 56, 
                        status = 'passed', 
                        comment = '', 
                        attachments = [
                            ''
                            ], 
                        action = '', 
                        expected_result = '', 
                        data = '', 
                        steps = [
                            None
                            ], )
                    ]
            )
        else:
            return ResultUpdate(
        )
        """

    def testResultUpdate(self):
        """Test ResultUpdate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
