# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.run_response import RunResponse

class TestRunResponse(unittest.TestCase):
    """RunResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RunResponse:
        """Test RunResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RunResponse`
        """
        model = RunResponse()
        if include_optional:
            return RunResponse(
                status = True,
                result = qaseio.models.run.Run(
                    id = 56, 
                    title = '', 
                    description = '', 
                    status = 56, 
                    status_text = '', 
                    start_time = '2021-12-30T19:23:59Z', 
                    end_time = '2021-12-30T19:23:59Z', 
                    public = True, 
                    stats = qaseio.models.run_stats.Run_stats(
                        total = 56, 
                        untested = 56, 
                        passed = 56, 
                        failed = 56, 
                        blocked = 56, 
                        skipped = 56, 
                        retest = 56, 
                        in_progress = 56, 
                        invalid = 56, ), 
                    time_spent = 56, 
                    environment = qaseio.models.run_environment.Run_environment(
                        title = '', 
                        description = '', 
                        slug = '', 
                        host = '', ), 
                    milestone = qaseio.models.run_milestone.Run_milestone(
                        title = '', 
                        description = '', ), 
                    custom_fields = [
                        qaseio.models.custom_field_value.CustomFieldValue(
                            id = 56, 
                            value = '', )
                        ], 
                    tags = [
                        qaseio.models.tag_value.TagValue(
                            title = '', 
                            internal_id = 56, )
                        ], 
                    cases = [
                        56
                        ], )
            )
        else:
            return RunResponse(
        )
        """

    def testRunResponse(self):
        """Test RunResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
