# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.milestones_api import MilestonesApi


class TestMilestonesApi(unittest.TestCase):
    """MilestonesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MilestonesApi()

    def tearDown(self) -> None:
        pass

    def test_create_milestone(self) -> None:
        """Test case for create_milestone

        Create a new milestone.
        """
        pass

    def test_delete_milestone(self) -> None:
        """Test case for delete_milestone

        Delete milestone.
        """
        pass

    def test_get_milestone(self) -> None:
        """Test case for get_milestone

        Get a specific milestone.
        """
        pass

    def test_get_milestones(self) -> None:
        """Test case for get_milestones

        Get all milestones.
        """
        pass

    def test_update_milestone(self) -> None:
        """Test case for update_milestone

        Update milestone.
        """
        pass


if __name__ == '__main__':
    unittest.main()
