# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.plans_api import PlansApi


class TestPlansApi(unittest.TestCase):
    """PlansApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlansApi()

    def tearDown(self) -> None:
        pass

    def test_create_plan(self) -> None:
        """Test case for create_plan

        Create a new plan.
        """
        pass

    def test_delete_plan(self) -> None:
        """Test case for delete_plan

        Delete plan.
        """
        pass

    def test_get_plan(self) -> None:
        """Test case for get_plan

        Get a specific plan.
        """
        pass

    def test_get_plans(self) -> None:
        """Test case for get_plans

        Get all plans.
        """
        pass

    def test_update_plan(self) -> None:
        """Test case for update_plan

        Update plan.
        """
        pass


if __name__ == '__main__':
    unittest.main()
