# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.suites_api import SuitesApi


class TestSuitesApi(unittest.TestCase):
    """SuitesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SuitesApi()

    def tearDown(self) -> None:
        pass

    def test_create_suite(self) -> None:
        """Test case for create_suite

        Create a new test suite.
        """
        pass

    def test_delete_suite(self) -> None:
        """Test case for delete_suite

        Delete test suite.
        """
        pass

    def test_get_suite(self) -> None:
        """Test case for get_suite

        Get a specific test suite.
        """
        pass

    def test_get_suites(self) -> None:
        """Test case for get_suites

        Get all test suites.
        """
        pass

    def test_update_suite(self) -> None:
        """Test case for update_suite

        Update test suite.
        """
        pass


if __name__ == '__main__':
    unittest.main()
