# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.authors_api import AuthorsApi


class TestAuthorsApi(unittest.TestCase):
    """AuthorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthorsApi()

    def tearDown(self) -> None:
        pass

    def test_get_author(self) -> None:
        """Test case for get_author

        Get a specific author.
        """
        pass

    def test_get_authors(self) -> None:
        """Test case for get_authors

        Get all authors.
        """
        pass


if __name__ == '__main__':
    unittest.main()
