# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.cases_api import CasesApi


class TestCasesApi(unittest.TestCase):
    """CasesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CasesApi()

    def tearDown(self) -> None:
        pass

    def test_bulk(self) -> None:
        """Test case for bulk

        Create test cases in bulk.
        """
        pass

    def test_case_attach_external_issue(self) -> None:
        """Test case for case_attach_external_issue

        Attach the external issues to the test cases.
        """
        pass

    def test_case_detach_external_issue(self) -> None:
        """Test case for case_detach_external_issue

        Detach the external issues from the test cases.
        """
        pass

    def test_create_case(self) -> None:
        """Test case for create_case

        Create a new test case.
        """
        pass

    def test_delete_case(self) -> None:
        """Test case for delete_case

        Delete test case.
        """
        pass

    def test_get_case(self) -> None:
        """Test case for get_case

        Get a specific test case.
        """
        pass

    def test_get_cases(self) -> None:
        """Test case for get_cases

        Get all test cases.
        """
        pass

    def test_update_case(self) -> None:
        """Test case for update_case

        Update test case.
        """
        pass


if __name__ == '__main__':
    unittest.main()
