# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.system_field_list_response import SystemFieldListResponse

class TestSystemFieldListResponse(unittest.TestCase):
    """SystemFieldListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SystemFieldListResponse:
        """Test SystemFieldListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SystemFieldListResponse`
        """
        model = SystemFieldListResponse()
        if include_optional:
            return SystemFieldListResponse(
                status = True,
                result = [
                    qaseio.models.system_field.SystemField(
                        title = '', 
                        slug = '', 
                        default_value = '', 
                        is_required = True, 
                        entity = 56, 
                        type = 56, 
                        options = [
                            qaseio.models.system_field_option.SystemFieldOption(
                                id = 56, 
                                title = '', 
                                slug = '', 
                                color = '', 
                                icon = '', 
                                is_default = True, 
                                read_only = True, )
                            ], )
                    ]
            )
        else:
            return SystemFieldListResponse(
        )
        """

    def testSystemFieldListResponse(self):
        """Test SystemFieldListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
