# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.shared_steps_api import SharedStepsApi


class TestSharedStepsApi(unittest.TestCase):
    """SharedStepsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SharedStepsApi()

    def tearDown(self) -> None:
        pass

    def test_create_shared_step(self) -> None:
        """Test case for create_shared_step

        Create a new shared step.
        """
        pass

    def test_delete_shared_step(self) -> None:
        """Test case for delete_shared_step

        Delete shared step.
        """
        pass

    def test_get_shared_step(self) -> None:
        """Test case for get_shared_step

        Get a specific shared step.
        """
        pass

    def test_get_shared_steps(self) -> None:
        """Test case for get_shared_steps

        Get all shared steps.
        """
        pass

    def test_update_shared_step(self) -> None:
        """Test case for update_shared_step

        Update shared step.
        """
        pass


if __name__ == '__main__':
    unittest.main()
