# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.system_field import SystemField

class TestSystemField(unittest.TestCase):
    """SystemField unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SystemField:
        """Test SystemField
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SystemField`
        """
        model = SystemField()
        if include_optional:
            return SystemField(
                title = '',
                slug = '',
                default_value = '',
                is_required = True,
                entity = 56,
                type = 56,
                options = [
                    qaseio.models.system_field_option.SystemFieldOption(
                        id = 56, 
                        title = '', 
                        slug = '', 
                        color = '', 
                        icon = '', 
                        is_default = True, 
                        read_only = True, )
                    ]
            )
        else:
            return SystemField(
        )
        """

    def testSystemField(self):
        """Test SystemField"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
