# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.defects_api import DefectsApi


class TestDefectsApi(unittest.TestCase):
    """DefectsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefectsApi()

    def tearDown(self) -> None:
        pass

    def test_create_defect(self) -> None:
        """Test case for create_defect

        Create a new defect.
        """
        pass

    def test_delete_defect(self) -> None:
        """Test case for delete_defect

        Delete defect.
        """
        pass

    def test_get_defect(self) -> None:
        """Test case for get_defect

        Get a specific defect.
        """
        pass

    def test_get_defects(self) -> None:
        """Test case for get_defects

        Get all defects.
        """
        pass

    def test_resolve_defect(self) -> None:
        """Test case for resolve_defect

        Resolve a specific defect.
        """
        pass

    def test_update_defect(self) -> None:
        """Test case for update_defect

        Update defect.
        """
        pass

    def test_update_defect_status(self) -> None:
        """Test case for update_defect_status

        Update a specific defect status.
        """
        pass


if __name__ == '__main__':
    unittest.main()
