# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.custom_fields_api import CustomFieldsApi


class TestCustomFieldsApi(unittest.TestCase):
    """CustomFieldsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomFieldsApi()

    def tearDown(self) -> None:
        pass

    def test_create_custom_field(self) -> None:
        """Test case for create_custom_field

        Create new Custom Field.
        """
        pass

    def test_delete_custom_field(self) -> None:
        """Test case for delete_custom_field

        Delete Custom Field by id.
        """
        pass

    def test_get_custom_field(self) -> None:
        """Test case for get_custom_field

        Get Custom Field by id.
        """
        pass

    def test_get_custom_fields(self) -> None:
        """Test case for get_custom_fields

        Get all Custom Fields.
        """
        pass

    def test_update_custom_field(self) -> None:
        """Test case for update_custom_field

        Update Custom Field by id.
        """
        pass


if __name__ == '__main__':
    unittest.main()
