# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.result_create_response import ResultCreateResponse

class TestResultCreateResponse(unittest.TestCase):
    """ResultCreateResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultCreateResponse:
        """Test ResultCreateResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResultCreateResponse`
        """
        model = ResultCreateResponse()
        if include_optional:
            return ResultCreateResponse(
                status = True,
                result = qaseio.models.result_create_response_all_of_result.ResultCreateResponse_allOf_result(
                    case_id = 56, 
                    hash = '', )
            )
        else:
            return ResultCreateResponse(
        )
        """

    def testResultCreateResponse(self):
        """Test ResultCreateResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
