# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.result_step import ResultStep

class TestResultStep(unittest.TestCase):
    """ResultStep unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultStep:
        """Test ResultStep
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResultStep`
        """
        model = ResultStep()
        if include_optional:
            return ResultStep(
                id = '',
                step_type = '',
                data = qaseio.models.result_step_data.ResultStepData(
                    action = '', 
                    expected_result = '', ),
                parent_id = '',
                execution = qaseio.models.result_step_execution.ResultStepExecution(
                    start_time = 1.337, 
                    end_time = 1.337, 
                    status = '', 
                    duration = 56, ),
                attachments = [
                    qaseio.models.result_attachment.ResultAttachment(
                        id = '', 
                        file_name = '', 
                        mime_type = '', 
                        file_path = '', 
                        content = '', 
                        size = 56, )
                    ],
                steps = [
                    None
                    ]
            )
        else:
            return ResultStep(
        )
        """

    def testResultStep(self):
        """Test ResultStep"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
