# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.result_create_case import ResultCreateCase

class TestResultCreateCase(unittest.TestCase):
    """ResultCreateCase unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultCreateCase:
        """Test ResultCreateCase
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResultCreateCase`
        """
        model = ResultCreateCase()
        if include_optional:
            return ResultCreateCase(
                title = '',
                suite_title = '',
                description = '',
                preconditions = '',
                postconditions = '',
                layer = '',
                severity = '',
                priority = ''
            )
        else:
            return ResultCreateCase(
        )
        """

    def testResultCreateCase(self):
        """Test ResultCreateCase"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
