# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.results_api import ResultsApi


class TestResultsApi(unittest.TestCase):
    """ResultsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ResultsApi()

    def tearDown(self) -> None:
        pass

    def test_create_result(self) -> None:
        """Test case for create_result

        Create test run result.
        """
        pass

    def test_create_result_bulk(self) -> None:
        """Test case for create_result_bulk

        Bulk create test run result.
        """
        pass

    def test_delete_result(self) -> None:
        """Test case for delete_result

        Delete test run result.
        """
        pass

    def test_get_result(self) -> None:
        """Test case for get_result

        Get test run result by code.
        """
        pass

    def test_get_results(self) -> None:
        """Test case for get_results

        Get all test run results.
        """
        pass

    def test_update_result(self) -> None:
        """Test case for update_result

        Update test run result.
        """
        pass


if __name__ == '__main__':
    unittest.main()
