# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.environments_api import EnvironmentsApi


class TestEnvironmentsApi(unittest.TestCase):
    """EnvironmentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EnvironmentsApi()

    def tearDown(self) -> None:
        pass

    def test_create_environment(self) -> None:
        """Test case for create_environment

        Create a new environment.
        """
        pass

    def test_delete_environment(self) -> None:
        """Test case for delete_environment

        Delete environment.
        """
        pass

    def test_get_environment(self) -> None:
        """Test case for get_environment

        Get a specific environment.
        """
        pass

    def test_get_environments(self) -> None:
        """Test case for get_environments

        Get all environments.
        """
        pass

    def test_update_environment(self) -> None:
        """Test case for update_environment

        Update environment.
        """
        pass


if __name__ == '__main__':
    unittest.main()
