# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.result_create_v2 import ResultCreateV2

class TestResultCreateV2(unittest.TestCase):
    """ResultCreateV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultCreateV2:
        """Test ResultCreateV2
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResultCreateV2`
        """
        model = ResultCreateV2()
        if include_optional:
            return ResultCreateV2(
                id = '',
                title = '',
                signature = '',
                testops_id = 56,
                execution = qaseio.models.result_execution.ResultExecution(
                    start_time = 1.337, 
                    end_time = 1.337, 
                    status = '', 
                    duration = 56, 
                    stacktrace = '', 
                    thread = '', ),
                fields = {
                    'key' : ''
                    },
                attachments = [
                    qaseio.models.result_attachment.ResultAttachment(
                        id = '', 
                        file_name = '', 
                        mime_type = '', 
                        file_path = '', 
                        content = '', 
                        size = 56, )
                    ],
                steps = [
                    qaseio.models.result_step.ResultStep(
                        id = '', 
                        step_type = '', 
                        data = qaseio.models.result_step_data.ResultStepData(
                            action = '', 
                            expected_result = '', ), 
                        parent_id = '', 
                        execution = qaseio.models.result_step_execution.ResultStepExecution(
                            start_time = 1.337, 
                            end_time = 1.337, 
                            status = '', 
                            duration = 56, ), 
                        attachments = [
                            qaseio.models.result_attachment.ResultAttachment(
                                id = '', 
                                file_name = '', 
                                mime_type = '', 
                                file_path = '', 
                                content = '', 
                                size = 56, )
                            ], 
                        steps = [
                            None
                            ], )
                    ],
                params = {
                    'key' : ''
                    },
                author = '',
                relations = qaseio.models.relation.Relation(
                    suite = qaseio.models.relation_suite.RelationSuite(
                        data = [
                            qaseio.models.relation_suite_item.RelationSuiteItem(
                                title = '', 
                                public_id = 56, )
                            ], ), ),
                muted = True,
                message = '',
                created_at = 1.337
            )
        else:
            return ResultCreateV2(
                title = '',
                execution = qaseio.models.result_execution.ResultExecution(
                    start_time = 1.337, 
                    end_time = 1.337, 
                    status = '', 
                    duration = 56, 
                    stacktrace = '', 
                    thread = '', ),
        )
        """

    def testResultCreateV2(self):
        """Test ResultCreateV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
